@@ -20,8 +20,12 @@ from .kernels import (
 from .likelihoods import Bernoulli, Gaussian
 from .mean_functions import Constant, Zero
 from .parameters import copy_dict_structure, initialise, transform
-from .sparse_gps import SVGP
 from .types import Dataset
-from .variational import VariationalGaussian, WhitenedVariationalGaussian
+from .variational_families import (
+    CollapsedVariationalGaussian,
+    VariationalGaussian,
+    WhitenedVariationalGaussian,
+)
+from .variational_inference import CollapsedVI, StochasticVI
 
-__version__ = "0.4.5"
+__version__ = "0.4.8"
